==> openshift-model-operator-6.6.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoadBalancerStrategyFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerStrategyFluentImpl<A extends LoadBalancerStrategyFluent<A>> extends BaseFluent<A> implements LoadBalancerStrategyFluent<A>{
  public LoadBalancerStrategyFluentImpl() {
  }
  public LoadBalancerStrategyFluentImpl(LoadBalancerStrategy instance) {
    this.withProviderParameters(instance.getProviderParameters()); 
    this.withScope(instance.getScope()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ProviderLoadBalancerParametersBuilder providerParameters;
  private String scope;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildProviderParameters instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProviderLoadBalancerParameters getProviderParameters() {
    return this.providerParameters!=null ?this.providerParameters.build():null;
  }
  public ProviderLoadBalancerParameters buildProviderParameters() {
    return this.providerParameters!=null ?this.providerParameters.build():null;
  }
  public A withProviderParameters(ProviderLoadBalancerParameters providerParameters) {
    _visitables.get("providerParameters").remove(this.providerParameters);
    if (providerParameters!=null){ this.providerParameters= new ProviderLoadBalancerParametersBuilder(providerParameters); _visitables.get("providerParameters").add(this.providerParameters);} else { this.providerParameters = null; _visitables.get("providerParameters").remove(this.providerParameters); } return (A) this;
  }
  public Boolean hasProviderParameters() {
    return this.providerParameters != null;
  }
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> withNewProviderParameters() {
    return new LoadBalancerStrategyFluentImpl.ProviderParametersNestedImpl();
  }
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> withNewProviderParametersLike(ProviderLoadBalancerParameters item) {
    return new LoadBalancerStrategyFluentImpl.ProviderParametersNestedImpl(item);
  }
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editProviderParameters() {
    return withNewProviderParametersLike(getProviderParameters());
  }
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editOrNewProviderParameters() {
    return withNewProviderParametersLike(getProviderParameters() != null ? getProviderParameters(): new ProviderLoadBalancerParametersBuilder().build());
  }
  public LoadBalancerStrategyFluent.ProviderParametersNested<A> editOrNewProviderParametersLike(ProviderLoadBalancerParameters item) {
    return withNewProviderParametersLike(getProviderParameters() != null ? getProviderParameters(): item);
  }
  public String getScope() {
    return this.scope;
  }
  public A withScope(String scope) {
    this.scope=scope; return (A) this;
  }
  public Boolean hasScope() {
    return this.scope != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerStrategyFluentImpl that = (LoadBalancerStrategyFluentImpl) o;
    if (providerParameters != null ? !providerParameters.equals(that.providerParameters) :that.providerParameters != null) return false;
    if (scope != null ? !scope.equals(that.scope) :that.scope != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(providerParameters,  scope,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (providerParameters != null) { sb.append("providerParameters:"); sb.append(providerParameters + ","); }
    if (scope != null) { sb.append("scope:"); sb.append(scope + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ProviderParametersNestedImpl<N> extends ProviderLoadBalancerParametersFluentImpl<LoadBalancerStrategyFluent.ProviderParametersNested<N>> implements LoadBalancerStrategyFluent.ProviderParametersNested<N>,Nested<N>{
    ProviderParametersNestedImpl(ProviderLoadBalancerParameters item) {
      this.builder = new ProviderLoadBalancerParametersBuilder(this, item);
    }
    ProviderParametersNestedImpl() {
      this.builder = new ProviderLoadBalancerParametersBuilder(this);
    }
    ProviderLoadBalancerParametersBuilder builder;
    public N and() {
      return (N) LoadBalancerStrategyFluentImpl.this.withProviderParameters(builder.build());
    }
    public N endProviderParameters() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoadBalancerStrategyFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerStrategyFluentImpl<A extends LoadBalancerStrategyFluent<A>> extends BaseFluent<A> implements LoadBalancerStrategyFluent<A>{
  public LoadBalancerStrategyFluentImpl() {
  }
  public LoadBalancerStrategyFluentImpl(LoadBalancerStrategy instance) {
    if (instance != null) {
      this.withProviderParameters(instance.getProviderParameters());
      this.withScope(instance.getScope());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ProviderLoadBalancerParametersBuilder providerParameters;
  private String scope;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildProviderParameters instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProviderLoadBalancerParameters getProviderParameters() {
    return this.providerParameters!=null ?this.providerParameters.build():null;
  }
  public ProviderLoadBalancerParameters buildProviderParameters() {
    return this.providerParameters!=null ?this.providerParameters.build():null;
  }
  public A withProviderParameters(ProviderLoadBalancerParameters providerParameters) {
    _visitables.get("providerParameters").remove(this.providerParameters);
    if (providerParameters!=null){ this.providerParameters= new ProviderLoadBalancerParametersBuilder(providerParameters); _visitables.get("providerParameters").add(this.providerParameters);} else { this.providerParameters = null; _visitables.get("providerParameters").remove(this.providerParameters); } return (A) this;
  }
  public Boolean hasProviderParameters() {
    return this.providerParameters != null;
  }
  public LoadBalancerStrategyFluentImpl.ProviderParametersNested<A> withNewProviderParameters() {
    return new LoadBalancerStrategyFluentImpl.ProviderParametersNestedImpl();
  }
  public LoadBalancerStrategyFluentImpl.ProviderParametersNested<A> withNewProviderParametersLike(ProviderLoadBalancerParameters item) {
    return new LoadBalancerStrategyFluentImpl.ProviderParametersNestedImpl(item);
  }
  public LoadBalancerStrategyFluentImpl.ProviderParametersNested<A> editProviderParameters() {
    return withNewProviderParametersLike(getProviderParameters());
  }
  public LoadBalancerStrategyFluentImpl.ProviderParametersNested<A> editOrNewProviderParameters() {
    return withNewProviderParametersLike(getProviderParameters() != null ? getProviderParameters(): new ProviderLoadBalancerParametersBuilder().build());
  }
  public LoadBalancerStrategyFluentImpl.ProviderParametersNested<A> editOrNewProviderParametersLike(ProviderLoadBalancerParameters item) {
    return withNewProviderParametersLike(getProviderParameters() != null ? getProviderParameters(): item);
  }
  public String getScope() {
    return this.scope;
  }
  public A withScope(String scope) {
    this.scope=scope; return (A) this;
  }
  public Boolean hasScope() {
    return this.scope != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerStrategyFluentImpl that = (LoadBalancerStrategyFluentImpl) o;
    if (!java.util.Objects.equals(providerParameters, that.providerParameters)) return false;

    if (!java.util.Objects.equals(scope, that.scope)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(providerParameters,  scope,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (providerParameters != null) { sb.append("providerParameters:"); sb.append(providerParameters + ","); }
    if (scope != null) { sb.append("scope:"); sb.append(scope + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ProviderParametersNestedImpl<N> extends ProviderLoadBalancerParametersFluentImpl<LoadBalancerStrategyFluentImpl.ProviderParametersNested<N>> implements LoadBalancerStrategyFluentImpl.ProviderParametersNested<N>,Nested<N>{
    ProviderParametersNestedImpl(ProviderLoadBalancerParameters item) {
      this.builder = new ProviderLoadBalancerParametersBuilder(this, item);
    }
    ProviderParametersNestedImpl() {
      this.builder = new ProviderLoadBalancerParametersBuilder(this);
    }
    ProviderLoadBalancerParametersBuilder builder;
    public N and() {
      return (N) LoadBalancerStrategyFluentImpl.this.withProviderParameters(builder.build());
    }
    public N endProviderParameters() {
      return and();
    }
    
  }
  
}
